LEAP's Key Manager
==================
.. image:: https://badge.fury.io/py/leap.keymanager.svg
    :target: http://badge.fury.io/py/leap.keymanager
.. image:: https://img.shields.io/pypi/dm/leap.keymanager.svg
    :target: http://badge.fury.io/py/leap.keymanager

The Key Manager is a `Nicknym`_ agent for the `LEAP`_ project, written in python using the `twisted`_ async framework.

.. _`Nicknym`: https://leap.se/nicknym
.. _`LEAP`: https://leap.se/docs/
.. _`twisted`: https://twistedmatrix.com/trac/


running tests
-------------

Use trial to run the test suite::

  trial leap.keymanager

License
=======

.. image:: https://raw.github.com/leapcode/bitmask_client/develop/docs/user/gpl.png

leap.keymanager is released under the terms of the `GNU GPL version 3`_ or later.

.. _`GNU GPL version 3`: http://www.gnu.org/licenses/gpl.txt
